package org.fax4j.common;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * This is a common basic implementation of the configuration holder.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.41.7
 */
public final class ConfigurationHolderImpl implements ConfigurationHolder
{
	/**The configuration*/
	private final Map<String,String> CONFIGURATION;
	/**The logger*/
	private final Logger LOGGER;

	/**
	 * This is the class constructor.
	 * 
	 * @param 	map
	 * 			The configuration as map
	 */
	public ConfigurationHolderImpl(Map<String,String> map)
	{
		super();
		
		//get logger
		LoggerManager loggerManager=LoggerManager.getInstance();
		this.LOGGER=loggerManager.getLogger();

		//get configuration
		Map<String,String> configuration=new HashMap<String,String>(map);
		this.CONFIGURATION=Collections.unmodifiableMap(configuration);
	}

	/**
	 * Returns the configuration.
	 *  
	 * @return	The configuration
	 */
	public final Map<String,String> getConfiguration()
	{
		return this.CONFIGURATION;
	}

	/**
	 * Returns the value from the component configuration based on the provided 
	 * configuration key.
	 * The value will be trimmed.<br>
	 * If the trimmed configuration value is an empty string,
	 * null will be returned instead.
	 *  
	 * @param 	key
	 * 			The configuration key
	 * @return	The value
	 */
	public final String getConfigurationValue(String key)
	{
		//get value
		String value=this.CONFIGURATION.get(key);
		
		//trim value
		if(value!=null)
		{
			value=value.trim();
			
			//set as null if empty string
			if(value.length()==0)
			{
				value=null;
			}
		}
		
		this.LOGGER.logDebug(new Object[]{"Extracted configuration for key: ",key," value: ",value},null);
		
		return value;
	}

	/**
	 * Returns the value from the component configuration based on the provided 
	 * configuration key.
	 * The value will be trimmed.<br>
	 * If the trimmed configuration value is an empty string,
	 * null will be returned instead.
	 *  
	 * @param 	key
	 * 			The configuration key (toString value will be used)
	 * @return	The value
	 */
	public final String getConfigurationValue(Enum<?> key)
	{
		//get string key
		String keyStr=key.toString();
		
		//get value
		String value=this.getConfigurationValue(keyStr);
		
		return value;
	}
}